@@ -23,6 +23,7 @@ Usage:
   opereto environments list [<search_pattern>]
   opereto environment <environment-name>
   opereto globals list [<search_pattern>]
+  opereto diagnostics <from_iso_date> <to_iso_date>
   opereto token
   opereto (-h | --help)
   opereto --version
@@ -67,6 +68,7 @@ Options:
     token                : Show the current token details
     -h,--help            : Show this help message
     --version            : Show this tool version
+
 """
 
 import os, sys
@@ -86,6 +88,8 @@ import traceback
 from docopt import docopt
 from distutils.version import LooseVersion
 from pyopereto.client import OperetoClient, OperetoClientError, process_running_statuses
+from pyopereto.diagnostics import run_diagnostics
+
 
 try:
     VERSION = pkg_resources.get_distribution("pyopereto").version
@@ -687,6 +691,13 @@ def _check_for_upgrade():
         logger.error('Failed to check for latest pyopereto version: {}'.format(str(e)))
 
 
+def diagnostics(arguments):
+
+    startdate = arguments['<from_iso_date>']
+    enddate = arguments['<to_iso_date>']
+    run_diagnostics(startdate, enddate)
+
+
 def main():
 
     _check_for_upgrade()
@@ -740,6 +751,8 @@ def main():
             local_dev(arguments)
         elif arguments['token']:
             print_token(arguments)
+        elif arguments['diagnostics']:
+            diagnostics(arguments)
 
     except Exception as e:
         logger.error(str(e))
